/// <reference types="react" />
import { StackNavigationProp } from '@react-navigation/stack';
import { DependencyContainer } from 'tsyringe';
import { Button } from './components/buttons/Button-api';
import { ReducerAction } from './contexts/reducers/store';
import Onboarding from './screens/Onboarding';
import { GenericFn } from './types/fn';
import { AuthenticateStackParams } from './types/navigators';
export declare enum SCREEN_TOKENS {
    SCREEN_TERMS = "screen.terms",
    SCREEN_ONBOARDING = "screen.onboarding",
    SCREEN_ONBOARDING_ITEM = "screen.onboarding.item"
}
export declare enum STACK_TOKENS {
    STACK_ONBOARDING = "stack.onboarding"
}
export declare enum FN_TOKENS {
    FN_ONBOARDING_DONE = "fn.onboardingDone"
}
export declare enum COMP_TOKENS {
    COMP_BUTTON = "comp.button"
}
export declare enum SERVICE_TOKENS {
    SERVICE_TERMS = "screen.terms"
}
export declare const TOKENS: {
    COMP_BUTTON: COMP_TOKENS.COMP_BUTTON;
    FN_ONBOARDING_DONE: FN_TOKENS.FN_ONBOARDING_DONE;
    STACK_ONBOARDING: STACK_TOKENS.STACK_ONBOARDING;
    SERVICE_TERMS: SERVICE_TOKENS.SERVICE_TERMS;
    SCREEN_TERMS: SCREEN_TOKENS.SCREEN_TERMS;
    SCREEN_ONBOARDING: SCREEN_TOKENS.SCREEN_ONBOARDING;
    SCREEN_ONBOARDING_ITEM: SCREEN_TOKENS.SCREEN_ONBOARDING_ITEM;
};
export type FN_ONBOARDING_DONE = (dispatch: React.Dispatch<ReducerAction<unknown>>, navigation: StackNavigationProp<AuthenticateStackParams>) => GenericFn;
export interface TokenMapping {
    [TOKENS.STACK_ONBOARDING]: React.FC;
    [TOKENS.SCREEN_TERMS]: React.FC;
    [TOKENS.SCREEN_ONBOARDING]: typeof Onboarding;
    [TOKENS.FN_ONBOARDING_DONE]: FN_ONBOARDING_DONE;
    [TOKENS.COMP_BUTTON]: Button;
}
export interface Container {
    init(): Container;
    resolve<K extends keyof TokenMapping>(token: K): TokenMapping[K];
    getContainer(): DependencyContainer;
}
export declare const ContainerContext: import("react").Context<Container | undefined>;
export declare const ContainerProvider: import("react").Provider<Container | undefined>;
export declare const useContainer: () => Container;
//# sourceMappingURL=container-api.d.ts.map